@@ -17,7 +17,10 @@ class AIS:
             'Vessel-Image': '005bf958a6548a79c6d3a42eba493e339624',
         })
         if proxy:
-            self.freeproxy = FreeProxy(proxy_config)
+            if proxy_config.get('proxy_config') is not None:
+                self.freeproxy = FreeProxy(**proxy_config.get('proxy_config'))
+            else:
+                self.freeproxy = FreeProxy()
             self.verbose_print("Searching for proxy...")
             self.session.proxies = self.freeproxy.get()
             self.verbose_print("Proxy found...")
@@ -134,7 +137,6 @@ class AIS:
 
         request_url = f"https://www.marinetraffic.com/en/reports?asset_type=vessels&columns={columns_url}&area_in={area_short}&time_of_latest_position_between=60,NaN"
         referer_url = f"https://www.marinetraffic.com/en/data/?asset_type=vessels&columns={columns_url}&area_in|in|{areas_long}|area_in={area_short}&time_of_latest_position_between|gte|time_of_latest_position_between=60,525600"
-
         self.session.headers['Referer'] = referer_url
 
         response = self.session.get(request_url)
